@@ -303,7 +303,7 @@ set_pypamtest_exception(PyObject *exc,
 
 	if (test_repr[0] != '\0' && failed != NULL) {
 		PyErr_Format(exc,
-			     "Error [%d]: Test case %s retured [%d]",
+			     "Error [%d]: Test case %s returned [%d]",
 			     perr, test_repr, failed->op_rv);
 	} else {
 		obj = Py_BuildValue(discard_const_p(char, "(i,s)"),
@@ -852,8 +852,8 @@ static int fill_conv_data(PyObject *py_echo_off,
 		return ENOMEM;
 	}
 
-	conv_data->out_info = new_conv_list(conv_count);
-	conv_data->out_err = new_conv_list(conv_count);
+	conv_data->out_info = new_conv_list(PAM_CONV_MSG_MAX);
+	conv_data->out_err = new_conv_list(PAM_CONV_MSG_MAX);
 	if (conv_data->out_info == NULL || conv_data->out_err == NULL) {
 		free_conv_data(conv_data);
 		return ENOMEM;
@@ -906,7 +906,7 @@ static int py_tc_list_to_cstruct_list(PyObject *py_test_list,
 PyDoc_STRVAR(RunPamTest__doc__,
 "Run PAM tests\n\n"
 "This function runs PAM test cases and reports result\n"
-"Paramaters:\n"
+"Parameters:\n"
 "service: The PAM service to use in the conversation (string)\n"
 "username: The user to run PAM conversation as\n"
 "test_list: Sequence of pypamtest.TestCase objects\n"
