@@ -361,10 +361,30 @@ static void test_pam_env_functions(void **state)
 
 	v = pam_getenv(test_ctx->ph, "KEY");
 	assert_non_null(v);
+
+#ifdef HAVE_OPENPAM
+	/*
+	 * Off-by-one error in pam_getenv()
+	 * https://www.openpam.org/wiki/Errata/2019-02-22
+	 */
+	if (*v == '=') {
+		v++;
+	}
+#endif
 	assert_string_equal(v, "value");
 
 	v = pam_getenv(test_ctx->ph, "KEY2");
 	assert_non_null(v);
+
+#ifdef HAVE_OPENPAM
+	/*
+	 * Off-by-one error in pam_getenv()
+	 * https://www.openpam.org/wiki/Errata/2019-02-22
+	 */
+	if (*v == '=') {
+		v++;
+	}
+#endif
 	assert_string_equal(v, "value2");
 
 	vlist = pam_getenvlist(test_ctx->ph);
